@@ -1,12 +1,12 @@
 checkRVersion <- function(quiet=FALSE)
   {
-    page2 <- scan(file="http://cran.r-project.org/src/base/R-2",
+    page2 <- scan(file="https://cran.r-project.org/src/base/R-2",
                   what="", quiet=TRUE)
-    page3 <- scan(file="http://cran.r-project.org/src/base/R-3",
+    page3 <- scan(file="https://cran.r-project.org/src/base/R-3",
                   what="", quiet=TRUE)
 
     combined <- c(page2, page3)
-    
+
     matches <- grep("R-[0-9]\\.[0-9]+\\.[0-9]+", combined, value=TRUE)
     versionList <- gsub("^.*R-([0-9].[0-9]+.[0-9]+).*$","\\1",matches)
     versionList <- numeric_version(versionList)
@@ -30,5 +30,5 @@ checkRVersion <- function(quiet=FALSE)
           }
         invisible( NULL );
       }
-    
+
   }
